@@ -32,16 +32,16 @@
 
 'use strict';
 
-var jsIdentifierRE = /^[a-z_$][a-z0-9_$]*$/i;
-var tripleQuotesRE = /'''/g;
-var SPACES = '          ';
+const jsIdentifierRE = /^[a-z_$][a-z0-9_$]*$/i;
+const tripleQuotesRE = /'''/g;
+const SPACES = '          ';
 
 function contains(str1, str2) {
   return str1.indexOf(str2) >= 0;
 }
 
 function newlineWrap(str) {
-  return str && '\n' + str + '\n';
+  return str && `\n${str}\n`;
 }
 
 function isObject(obj) {
@@ -53,7 +53,7 @@ function parseIndent(indent) {
     case 'string':
       return indent.slice(0, 10);
     case 'number':
-      var n = Math.max(0, Math.min(10, Math.floor(indent)));
+      const n = Math.max(0, Math.min(10, Math.floor(indent)));
       return SPACES.slice(0, n);
     default:
       return 0;
@@ -75,14 +75,10 @@ function indentLines(indent, str) {
 }
 
 function singleQuoteStringify(str) {
-  return (
-    "'" +
-    JSON.stringify(str)
-      .slice(1, -1)
-      .replace(/\\"/g, '"')
-      .replace(/'/g, "\\'") +
-    "'"
-  );
+  return `'${JSON.stringify(str)
+    .slice(1, -1)
+    .replace(/\\"/g, '"')
+    .replace(/'/g, "\\'")}'`;
 }
 
 function quoteType(str) {
@@ -96,72 +92,75 @@ function onelineStringify(str) {
 }
 
 function buildKeyPairs(visitNode, indent, obj) {
-  return Object.keys(obj).map(function addKey(key) {
-    var value = obj[key];
+  return Object.keys(obj).map(key => {
+    const value = obj[key];
     if (!key.match(jsIdentifierRE)) {
       key = onelineStringify(key);
     }
-    var serializedValue = visitNode(value, {
+    let serializedValue = visitNode(value, {
       bracesRequired: !indent,
     });
     if (indent) {
       serializedValue =
         isObject(value) && Object.keys(value).length > 0
-          ? '\n' + indentLines(indent, serializedValue)
-          : ' ' + serializedValue;
+          ? `\n${indentLines(indent, serializedValue)}`
+          : ` ${serializedValue}`;
     }
-    return key + ':' + serializedValue;
+    return `${key}:${serializedValue}`;
   });
 }
 
 function visitArray(visitNode, indent, arr) {
-  var items = arr.map(function visitElement(value) {
+  const items = arr.map(value => {
     return visitNode(value, {
       bracesRequired: true,
     });
   });
-  var serializedItems = indent
+  const serializedItems = indent
     ? newlineWrap(indentLines(indent, items.join('\n')))
     : items.join(',');
-  return '[' + serializedItems + ']';
+  return `[${serializedItems}]`;
 }
 
 function visitObject(visitNode, indent, obj, arg) {
-  var bracesRequired = arg.bracesRequired;
-  var keypairs = buildKeyPairs(visitNode, indent, obj);
+  const bracesRequired = arg.bracesRequired;
+  const keypairs = buildKeyPairs(visitNode, indent, obj);
 
   if (keypairs.length === 0) return '{}';
 
   if (indent) {
-    var keyPairLines = keypairs.join('\n');
+    const keyPairLines = keypairs.join('\n');
     if (bracesRequired) {
-      return '{' + newlineWrap(indentLines(indent, keyPairLines)) + '}';
+      return `{${newlineWrap(indentLines(indent, keyPairLines))}}`;
     }
     return keyPairLines;
   }
 
-  var serializedKeyPairs = keypairs.join(',');
+  const serializedKeyPairs = keypairs.join(',');
   if (bracesRequired) {
-    return '{' + serializedKeyPairs + '}';
+    return `{${serializedKeyPairs}}`;
   }
   return serializedKeyPairs;
 }
 
 function visitString(visitNode, indent, str) {
-  var string;
   if (str.indexOf('\n') === -1 || !indent) {
     return onelineStringify(str);
   }
-  string = str.replace(/\\/g, '\\\\').replace(tripleQuotesRE, "\\'''");
-  return "'''" + newlineWrap(indentLines(indent, string)) + "'''";
+  const string = str.replace(/\\/g, '\\\\').replace(tripleQuotesRE, "\\'''");
+  return `'''${newlineWrap(indentLines(indent, string))}'''`;
 }
 
+// disabling consistent return so cson parser handles undefined like JSON.stringify does
 function stringify(data, visitor, indent) {
-  if (typeof data === 'function' || typeof data === 'undefined')
+  if (typeof data === 'function' || typeof data === 'undefined') {
+    // eslint-disable-next-line consistent-return
     return undefined;
+  }
+
   indent = parseIndent(indent);
 
-  var normalized = JSON.parse(JSON.stringify(data, visitor));
+  const normalized = JSON.parse(JSON.stringify(data, visitor));
 
   function visitNode(node, options) {
     if (options == null) {
@@ -170,11 +169,11 @@ function stringify(data, visitor, indent) {
 
     switch (typeof node) {
       case 'boolean':
-        return '' + node;
+        return `${node}`;
 
       case 'number':
         if (isFinite(node)) {
-          return '' + node;
+          return `${node}`;
         }
         return 'null';
 
@@ -190,10 +189,13 @@ function stringify(data, visitor, indent) {
         return visitObject(visitNode, indent, node, options);
 
       default:
+        // eslint-disable-next-line consistent-return
         return undefined;
     }
   }
 
+  // eslint-disable-next-line consistent-return
   return visitNode(normalized);
 }
+
 module.exports = stringify;
